@@ -15,6 +15,12 @@ class TeamInline(admin.TabularInline):
     extra = 0
 
 
+class BusinessProviderInline(admin.TabularInline):
+    model = BusinessProvider
+    exclude = ('urlid', 'is_backlink', 'allow_create_backlink')
+    extra = 0
+
+
 class ProjectAdmin(DjangoLDPAdmin):
     list_display = ('urlid', 'customer', 'name', 'captain', 'status', 'jabberID')
     exclude = ('urlid', 'is_backlink', 'allow_create_backlink', 'jabberID', 'jabberRoom')
@@ -22,7 +28,7 @@ class ProjectAdmin(DjangoLDPAdmin):
         'status', 'captain__urlid', 'customer__urlid', 'customer__name',\
         'businessProvider__urlid', 'businessProvider__name']
     ordering = ['urlid']
-    inlines = [TeamInline]
+    inlines = [BusinessProviderInline, TeamInline]
 
     def get_queryset(self, request):
         # Hide distant projects
