@@ -25,8 +25,7 @@ class Customer(Model):
     companyRegister = models.CharField(max_length=255, null=True, blank=True)
     first_name = models.CharField(max_length=255, null=True, blank=True)
     last_name = models.CharField(max_length=255, null=True, blank=True)
-    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_customers", on_delete=models.SET_NULL,
-                              null=True)
+    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_customers", null=True, blank=True, on_delete=models.SET_NULL)
     role = models.CharField(max_length=255, null=True, blank=True)
     email = models.EmailField(null=True, blank=True)
     phone = models.CharField(max_length=255, null=True, blank=True)
@@ -72,7 +71,7 @@ class Project(Model):
     status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Private', null=True, blank=True)
     number = models.PositiveIntegerField(default=auto_increment_project_number, editable=False)
     creationDate = models.DateField(auto_now_add=True)
-    customer = models.ForeignKey(Customer, on_delete=models.SET_NULL, null=True, blank=True)
+    customer = models.ForeignKey(Customer, on_delete=models.SET_NULL, related_name='projects', null=True, blank=True)
     captain = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, blank=True, null=True,
                                 related_name='+')
     driveID = models.TextField(null=True, blank=True)
